<?php

namespace Koneko\VuexyAdminModule\App\Imports;

use Carbon\Carbon;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\ToCollection;

class SATCodigoPostalImport implements ToCollection
{
    public function collection(Collection $collection)
    {
        $batchSize = 1000;
        $batchData = [];
        $processedRows = 0;

        foreach ($collection as $key => $row) {
            if ($key < 7 || !$row[1]) {
                continue;
            }

            $requestArray = [
                'c_codigo_postal' => $row[0],
                'c_estado' => $row[1],
                'c_municipio' => $row[2],
                'c_localidad' => $row[3],
                'estimulo_franja_fronteriza' => $row[4],
                'fecha_inicio_de_vigencia' => $row[5] ?
                    Carbon::instance(\PhpOffice\PhpSpreadsheet\Shared\Date::excelToDateTimeObject($row[5])) :
                    null,
                'fecha_fin_de_vigencia' => $row[6] ?
                    Carbon::instance(\PhpOffice\PhpSpreadsheet\Shared\Date::excelToDateTimeObject($row[6])) :
                    null,
            ];

            $batchData[] = $requestArray;
            $processedRows++;

            if (count($batchData) >= $batchSize) {
                $this->insertBatch($batchData);
                $batchData = [];
            }
        }

        if (!empty($batchData)) {
            $this->insertBatch($batchData);
        }

        echo "\n\033[32mImport completed: Processed $processedRows rows.\033[0m\n";
    }

    private function insertBatch(array $batchData)
    {
        try {
            DB::table('sat_codigo_postal')->upsert(
                $batchData,
                [
                    'c_codigo_postal'
                ],
                [
                    'c_estado',
                    'c_municipio',
                    'c_localidad',
                    'estimulo_franja_fronteriza',
                    'fecha_inicio_de_vigencia',
                    'fecha_fin_de_vigencia'
                ]
            );
        } catch (\Exception $e) {
            echo "Error in batch: " . $e->getMessage() . "\n";

            foreach ($batchData as $row) {
                echo "Row data: " . json_encode($row) . "\n";
            }
        }
    }
}
